#
# spec file for package gnome-doc-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-doc-utils
Version:        0.20.10
Release:        22.2
Summary:        A Collection of Documentation Utilities for GNOME
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
URL:            https://www.gnome.org
Source0:        https://download.gnome.org/sources/gnome-doc-utils/0.20/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM gnome-doc-utils-fig-path.patch bgo#682776 dimstar@opensuse.org -- Fix linking of figs in subfolders.
Patch0:         gnome-doc-utils-fig-path.patch
# PATCH-FIX-UPSTREAM gnome-doc-utils-port-python3.patch -- Port to python3
Patch1:         gnome-doc-utils-port-python3.patch

BuildRequires:  docbook_4
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  python-rpm-macros
%if %suse_version > 1500
BuildRequires:  python3-libxml2
%else
BuildRequires:  python3-libxml2-python
%endif
# needed for xmllint
BuildRequires:  libxml2-tools
BuildRequires:  libxslt-devel
BuildRequires:  pkgconfig
Requires:       libxslt
%if %suse_version > 1500
Requires:       python3-libxml2
%else
Requires:       python3-libxml2-python
%endif
BuildArch:      noarch

%description
The gnome-doc-utils package is a collection of documentation
utilities for the GNOME project. It contains utilities for building
documentation and auxiliary files in a source tree. It also contains
the DocBook XSLT stylesheets that were once distributed with Yelp.

%package -n xml2po
Summary:        Tool to extract translatable content from XML documents
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
%if %suse_version > 1500
BuildRequires:  python3-libxml2
%else
BuildRequires:  python3-libxml2-python
%endif

%description -n xml2po
xml2po is a Python program which extracts translatable content from
free-form XML documents and outputs gettext compatible POT files.

%package devel
Summary:        A Collection of Documentation Utilities for GNOME
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/GUI/GNOME
Requires:       %{name} = %{version}
# For the validation with xsltproc to use a local DTD
Requires:       docbook_4
Requires:       xml2po-devel

%description devel
The gnome-doc-utils package is a collection of documentation
utilities for the GNOME project. It contains utilities for building
documentation and auxiliary files in a source tree. It also contains
the DocBook XSLT stylesheets that were once distributed with Yelp.

%package -n xml2po-devel
Summary:        Pkgconfig file for xml2po
License:        GPL-2.0-or-later
Group:          System/GUI/GNOME
Requires:       xml2po = %{version}

%description -n xml2po-devel
xml2po is a Python program which extracts translatable content from
free-form XML documents and outputs gettext compatible POT files.

%lang_package

%prep
%autosetup -p1

%build
export LANG=C.UTF-8
%configure \
	--disable-scrollkeeper \
	%{nil}
%make_build pkgconfigdir=%{_datadir}/pkgconfig

%install
%make_install pkgconfigdir=%{_datadir}/pkgconfig
%find_lang %{name} %{?no_lang_C}
%find_lang gnome-doc-make %{?no_lang_C} %{name}.lang
%find_lang gnome-doc-xslt %{?no_lang_C} %{name}.lang
%fdupes %{buildroot}/%{_prefix}
%python3_fix_shebang

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/gnome-doc-make/
%doc %{_datadir}/gnome/help/gnome-doc-make/C/
%dir %{_datadir}/gnome/help/gnome-doc-xslt/
%doc %{_datadir}/gnome/help/gnome-doc-xslt/C/
%{_bindir}/gnome-doc-tool
%dir %{_datadir}/gnome-doc-utils
%{_datadir}/gnome-doc-utils/icons
%{_datadir}/gnome-doc-utils/watermarks
%{_datadir}/xml/gnome
%{_datadir}/xml/mallard

%files -n xml2po
%license xml2po/COPYING
%doc xml2po/AUTHORS xml2po/ChangeLog xml2po/NEWS xml2po/README
%{_bindir}/xml2po
%{python3_sitelib}/xml2po
%{_mandir}/man?/xml2po*%{ext_man}

%files devel
%{_bindir}/gnome-doc-prepare
%dir %{_datadir}/aclocal
%{_datadir}/aclocal/gnome-doc-utils.m4
%{_datadir}/pkgconfig/gnome-doc-utils.pc
%{_datadir}/gnome-doc-utils/gnome-doc-utils.make
%{_datadir}/gnome-doc-utils/templates
%{_datadir}/gnome-doc-utils/template*.*

%files -n xml2po-devel
%{_datadir}/pkgconfig/xml2po.pc

%files lang -f %{name}.lang

%changelog
* Thu Feb 22 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Mon Jan 17 2022 Michael Gorse <mgorse@suse.com>
- Add python-rpm-macros to BuildRequires (boo#1194754).
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Aug 31 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add python3-libxml2 as runtime dependency (up to CODE15, the
  package was called python3-libxml2-python, conditionally added).
* Wed Aug  4 2021 Yifan Jiang <yfjiang@suse.com>
- Adapt BuildRequires for SLE15 / Leap 15.x on xml2po.
* Fri Feb 19 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update gnome-doc-utils-port-python3.patch based on the patch used
  by Fedora (https://src.fedoraproject.org/rpms/gnome-doc-utils).
* Mon Feb 10 2020 Frederic Crozat <fcrozat@suse.com>
- Set encoding before building to fix a build error in SLE.
- Adapt BuildRequires for SLE15 / Leap 15.x.
* Thu Feb  6 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add gnome-doc-utils-port-python3.patch: Port to python3.
  Following this, replace python2-libxml2 with python3-libxml2
  BuildRequires and Requires.
- Modernize spec and tweak fdupes call.
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sat Aug 24 2019 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description. Update summaries.
* Fri Aug  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Use python2-libxml2 as a name for the libxml2 python bindings.
  This is provided by the new libxml2 package as the python
  module name should be $PYTHON_INTERP-$PACKAGENAME
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 17 2013 fcrozat@suse.com
- Remove dependency on scrollkeeper in devel package, all packages
  have migrated to yelp-tools (aka die scrollkeeper die).
* Wed Mar 20 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Wed Aug 29 2012 dimstar@opensuse.org
- Add gnome-doc-utils-fig-path.patch: Fix linking of figures in
  subfolders, where a relative path to ../../C will not do the
  right thing (gnome-devel-docs 3.5.90 contains such cases).
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 0.20.10:
  + Fixed problem with dist and install with too many files
  + Updated translations.
* Wed Mar 21 2012 vuntz@opensuse.org
- Update to version 0.20.9:
  + Temporarily adding RNG files back for compatibility.
* Mon Mar 19 2012 zaitor@opensuse.org
- Update to version 0.20.8:
  + Don't call RNG files, removed in 0.20.7
* Fri Mar  2 2012 dimstar@opensuse.org
- Update to version 0.20.7:
  + Use gawk --traditional option instead of -W compat
  + Added support for silent rules to gnome-doc-utils.make
  + Fixed xml2po.pc to not Require libxml.pc
  + Added --disable-documentation build option
  + Dropped Mallard definitions from gnome-doc-utils
  + Updated translations.
- Remove libxml2-devel Requires from xml2po-devel package: the .pc
  file no longer references libxml.
- Remove obsoleted conditions for openSUSE <= 11.1.
* Sat Feb 25 2012 coolo@suse.com
- Add libxml2-tools BuildRequires for xmllint, now that libxml2 got
  split.
- Remove python BuildRequires and %%py_requires: we only need a
  minimal python, which libxml2-python will bring in both cases.
* Thu Dec 22 2011 vuntz@opensuse.org
- Own %%{_datadir}/aclocal to fix build without automake/autoconf.
* Fri May 27 2011 vuntz@opensuse.org
- Add docbook_4 Requires to devel subpackage: packages building
  with gnome-doc-utils support will use xsltproc to validate files,
  and we want ot use a local DTD instead of fetching one from the
  internet.
* Tue Apr 26 2011 fcrozat@novell.com
- Update to version 0.20.6:
  + Updated Mallard schema.
  + Fixed 'make pot' rule for Mallard.
  + Updated translations.
* Tue Mar 22 2011 fcrozat@novell.com
- Update to version 0.20.5:
  + Updated Mallard RNG files
  + Updated translations.
* Thu Mar  3 2011 fcrozat@novell.com
- Update to version 0.20.4:
  + Use /bin/bash in gnome-doc-tool
  + Add xml:lang attribute to translated Mallard pages
  + Handle title and desc elements in Mallard tables
  + Updated translations.
* Sun Feb 13 2011 vuntz@opensuse.org
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 21 2010 vuntz@opensuse.org
- Update to version 0.20.3:
  + Fixed nested command substitution in gnome-doc-utils.make.
  + Updated translations.
* Thu Oct 14 2010 vuntz@opensuse.org
- Use Recommends instead of Requires for the lang package.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 0.20.2:
  + Updated translations.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 0.20.1:
  + Improved support for SVG imagedata
  + Updated translations.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 0.20.0:
  + Updated translations.
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 0.19.5:
  + Updated the Mallard RNG schema.
  + Updated translations:
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 0.19.4:
  + Bold userinput inside programlisting
  + Updated translations.
* Tue Jan 26 2010 vuntz@opensuse.org
- Update to version 0.19.3:
  + Fixed shading with rowspans, bgo#606986
  + Implemented text titles
  + Updated translations.
* Tue Jan 12 2010 vuntz@opensuse.org
- Update to version 0.19.2:
  + Added 'css' command for Mallard documents
  + Fixed theme.color.text default, was white-on-white
  + Implemented previous and next links for Mallard documents
  + Updated translations.
* Wed Jan  6 2010 vuntz@opensuse.org
- Update to version 0.19.1:
  + Importing Mallard XSLT changes from yelp-xsl
  - Added support for audio and video in Mallard HTML output
  - Moved most automatic link logic into common XSLT
  - Implemented sorting of link trails
  - Implemented link groups on Mallard guide pages
  - Added support for Mallard span element
  - Added condensed list style for Mallard lists
  - Made various parts of the Mallard XSLT more extensible
  - Changed Mallard Cache files to use new namespace
  + Added Mallard HTML output to gnome-doc-tool
  + Added --custom-xslt option to gnome-doc-tool
  + Compile mo files before running xml2po
  + Properly clean mo files in build utilities
  + Updated translations.
- Drop gnome-doc-utils-make-parallel.patch: fixed upstream.
- Make the build noarch.
- Remove en@shaw locale on 11.2 and earlier.
- Split xml2po tool in xml2po and xml2po-devel subpackages.
- Make gnome-doc-utils-devel Requires xml2po-devel, to make sure no
  build is broken because of the split.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 0.18.1:
  + Fixed Makefile.am to byte-compile Python files, bug #596702
  + Updated translations.
- Complete gnome-doc-utils-make-parallel.patch with commit
  ce05d9fd, and reenable parallel build.
* Thu Nov 26 2009 dimstar@opensuse.org
- Parallel build still has chances to fail. Disabling for now.
* Wed Nov 25 2009 dimstar@opensuse.org
- Add gnome-doc-utils-make-parallel.patch to solve parallel build
  failures (patch taken from upstream git).
* Mon Sep 28 2009 vuntz@opensuse.org
- Update to version 0.18.0:
  + Replaced Mallard copyright element with credit
  + Fixed model for external-namespace elements in info context
  + Fixed gnome-doc-utils.make parallel build failure, bgo#595197
  + Updated translations.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.17.5:
  + mal2html: Handle link roles on automatic and inline links
  + Updated translations.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 0.17.4:
  + Don't let "twocolumn" tables collapse in Mallard documents
  + Use AC_MSG_* when checking for gnome-doc-utils, bgo#571300
  + Work around buggy OpenSolaris awk
  + Substantial changes to xml2po
  + Work on xml2po Mallard mode
  + Fix misspelling of 'description'
  + Updated translations.
* Wed Aug 12 2009 dominique-obs@leuenberger.net
- Define new python macros on openSUSE <= 11.1.
* Sun Aug  9 2009 coolo@novell.com
- use new python macros
* Wed Jul 29 2009 vuntz@novell.com
- Update to version 0.17.3:
  + Added initial work on a Mallard xml2po mode
  + Internationalization work on Mallard stylesheets
  + Fixed example in Mallard document
  + Preserve exiting PYTHONPATH in bootstrap
  + Addressed RTL issues in Mallard stylesheets
  + Updated translations.
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 0.17.2:
  + Added build magic for Mallard documents
  + Fixed various validity errors in the Mallard spec
  + Created a (not yet complete) DocBook->Mallard reference
  + Fixed various problems with the Mallard RNG schema
  + Various additions to (still incomplete) Mallard spec
  + Fixed DocBook menuchoice seperator in RTL, bgo#579278
  + Install xml2po modes in /usr/lib/python2.x/ to respect FHS,
    bgo#528099
  + Remove ending dot in translator-credits comment [xml2po],
    bgo#398541
  + Make all xml2po modes inherit from basic mode
  + Fixed typos in xml2po man page, bgo#586089
  + Updated translations.
- Add libxml2-python BuildRequires since xml2po is called during
  the build now.
- Package is not noarch anymore since we use py_sitedir.
- Add py_requires.
* Mon Jun 15 2009 vuntz@novell.com
- Update to version 0.17.1:
  + Integrated Mallard support
  + Fix file-not-found warnings from config.status
- Add libxml2-devel Requires to devel package.
* Wed Apr 15 2009 vuntz@novell.com
- Update to version 0.16.1:
  + Use new hashlib module instead of md5, bgo#576161
  + Updated transations.
* Mon Mar 16 2009 vuntz@novell.com
- Update to version 0.16.0:
  + Updated translations.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Mon Mar  9 2009 vuntz@novell.com
- Split off a lang package.
- Put back scrollkeeper in Requires (of the devel package this
  time). It's really needed.
- Move some files to the devel package, where they belong.
* Mon Mar  2 2009 mboman@suse.de
- Update to version 0.15.2:
  + More RTL fixes for bgo#563559
  + Translation updates
- Completly remove gnome-doc-utils-permissive.patch
- Remove scrollkeeper from BuildRequires/Requires
- Remove AutoReqProv since it's default
- Add libxslt to Requires
* Mon Feb  2 2009 mboman@suse.de
- Update to version 0.15.1:
  + Fixed some RTL issues, thanks to muayyad alsadi, bgo#563559
  + Translation updates
- Comment out gnome-doc-utils-permissive.patch to see if packages
  builds properly when it's not in place.
- Remove gnome-common from BuildRequires
* Sun Jan 25 2009 vuntz@novell.com
- Remove useless BuildRequires/Requires on libgnome.
- Use fdupes.
* Mon Jan 12 2009 mboman@suse.de
- Update to version 0.14.2:
  + Translation updates
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.14.1:
  + Fixed some LTR issues, more remain on bug bgo#563559
  + chmod +x gnome-doc-{tool,prepare} on configure, bgo#557732
  + Symlink non-localized figured to C figures, bgo#557227
  + Translation updates
* Tue Sep 23 2008 mboman@suse.de
- Update to version 0.14.0:
  + Translation updates.
* Thu Sep  4 2008 maw@suse.de
- Don't require glib2-devel to build.
- Do require pkg-config to build.
* Sat Aug 30 2008 mboman@novell.com
- Updated to version 0.13.1:
  + Fixed UnicodeDecodeError in xml2po
  + Correctly handle content and tooltips for links to anchors
  + Don't reprocess book titles when title and bookinfo/title exist
  + Remove GLib build dependency; include glib-gettext.m4 [bgo#510915]
  + Updated translations
- Removed gnome-doc-utils-bnc408363-unicodeerror.patch. Fixed upstream.
* Fri Jul 25 2008 vuntz@novell.com
- Tag patch.
- Add gnome-doc-utils-bnc408363-unicodeerror.patch to fix an error
  in xml2po (bnc#408363).
* Fri Mar 14 2008 maw@suse.de
- Update to version 0.12.2:
  + Added DOCTYPE decls to HTML and XHTML pages
  + Adde EXSLT set to the excluded prefixes
  + Updated translations.
* Mon Feb 18 2008 maw@suse.de
- Update to version 0.12.1:
  + Chunks work without id attributes
  + Don't use the title as a label for qandadiv etc
  + Added support for manual indeces
  + Various other fixes
  + Updated translations.
* Fri Sep 14 2007 hpj@suse.de
- Reverted back to version 0.10.3, so the reverted Yelp will work
  correctly.
* Thu Aug 30 2007 maw@suse.de
- Update to version 0.11.2:
  * Added db2html.division.div.content.mode
  * Added support for manual indexes
  * Fixed the mime attribute in OMF output
  * Worked on the HTML output for refentry
  * Switched to set:has-same-node for node comparisons
  * Updated translations.
* Thu Aug  2 2007 mauro@suse.de
- Update to version 0.11.1
- Bugfixes for #456700.
* Wed Apr 11 2007 maw@suse.de
- Update to version 0.10.3
  * general:
    Use gawk -W compat whenever $(AWK) is gawk (Shaun McCance)
  * tools:
    Don't call ScrollKeeper when it's not installed; bug #410715
    (Shaun McCance)
  * xml2po:
    Display xsltproc invocation, honor its exit status, and pull
    the source from srcdir; bugzilla.gnome.org #169324 (Danilo Šegan)
  * Updated translations:
    gl   (Ignacio Casal Quinteiro)
    sq   (Laurent Dhima)
* Mon Mar 26 2007 maw@suse.de
- Update to version 0.10.1
- fixes for b.g.o 416933, 409292, and 169324.
* Thu Mar  1 2007 sbrabec@suse.cz
- Be even more permissive.
* Mon Feb 26 2007 sbrabec@suse.cz
- Be more permissive for incorrectly formatted docs.
* Mon Feb 19 2007 maw@suse.de
- Update to version 0.9.2.
* Mon Jan 29 2007 sbrabec@suse.cz
- Build as noarch (patch from Andreas Hanke, #237146).
* Thu Dec 14 2006 maw@suse.de
- Move to /usr.
* Fri Oct 13 2006 danw@suse.de
- Remove dead patch
* Tue Oct 10 2006 jhargadon@suse.de
- split out the devel files into a -devel package
* Wed Sep 13 2006 jhargadon@suse.de
- update to version 0.8.0
- Use an XSLT namespace alias for XInclude output
- Updated translations
* Mon Aug 21 2006 jhargadon@suse.de
- update to version 0.7.2
- updated translations
* Fri Aug 11 2006 jhargadon@suse.de
- update to version 0.7.1
- Added support for the LINGUAS environment variable
- Some fixes for HTML generation
- Fixed attribute handling
- updated translations
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.5.3.
* Wed Nov 30 2005 gekker@suse.de
- Update to version 0.4.4
* Tue Oct  4 2005 sbrabec@suse.cz
- Updated to version 0.4.2.
* Tue Sep  6 2005 sbrabec@suse.cz
- Updated to version 0.4.0.
* Mon Sep  5 2005 gekker@suse.de
- Update to version 0.3.3 (GNOME 2.12)
* Wed Aug 10 2005 sbrabec@suse.cz
- Do not require -devel packages.
* Mon Aug  8 2005 sbrabec@suse.cz
- Use minimal build environment to break build loop.
* Thu Jul 28 2005 sbrabec@suse.cz
- Updated to version 0.3.2.
- Fixed dependency on libxml2-python (#98757).
* Fri Jul 22 2005 gekker@suse.de
- Update to version 0.3.1
- Remove previous patch
* Wed Jul  6 2005 clahey@suse.de
- Added patches to update to cvs.
- Called auto* to get changes from cvs.
- Added dep on libxml2-devel.
* Fri Jun 17 2005 gekker@suse.de
- Update to version 0.2.0
* Wed Mar  9 2005 gekker@suse.de
- Updating to version 0.1.3 (GNOME 2.10).
* Wed Feb  2 2005 clahey@suse.de
- Updating to version 0.1.2.
* Mon Jan 24 2005 ro@suse.de
- fix lib64 build
* Mon Jan 24 2005 clahey@suse.de
- Initial import.
